@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 15:00:05
-@LastEditTime: 2023-01-04 15:04:40
+@LastEditTime: 2023-02-10 10:52:08
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -233,12 +233,20 @@ class PrizeRosterListHandler(ClientBaseHandler):
         order_base_model = OrderBaseModel(context=self)
         page_list = order_base_model.get_prize_roster_list(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, open_id=open_id, order_no=order_no, goods_type=goods_type, prize_type=prize_type, logistics_status=logistics_status, prize_status=prize_status, pay_status=pay_status, page_size=page_size, page_index=page_index, page_count_mode=page_count_mode)
         if page_count_mode == "total":
-            total = page_list[1]
-            page_list = self.business_process_executed(page_list[0], ref_params=ref_params)
+            if len(page_list) > 0:
+                total = page_list[1]
+                page_list = self.business_process_executed(page_list[0], ref_params=ref_params)
+            else:
+                total = 0
+                page_list = []
             return_info = PageInfo(page_index, page_size, total, page_list)
         elif page_count_mode == "next":
-            is_next = page_list[1]
-            page_list = self.business_process_executed(page_list[0], ref_params=ref_params)
+            if len(page_list) > 0:
+                is_next = page_list[1]
+                page_list = self.business_process_executed(page_list[0], ref_params=ref_params)
+            else:
+                is_next = False
+                page_list = []
             return_info = WaterPageInfo(page_list, is_next)
         else:
             return_info = self.business_process_executed(page_list, ref_params=ref_params)
