@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2023-02-03 19:04:07
+@LastEditTime: 2023-02-15 15:06:46
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -270,12 +270,12 @@ class CumulativeSignHandler(ClientBaseHandler):
 
 class InviteNewUserHandler(ClientBaseHandler):
     """
-    :description: 处理邀请用户任务
+    :description: 处理邀请用户任务(被邀请人进入调用)
     """
     @filter_check_params("invite_user_id,login_token", check_user_code=True)
     def get_async(self):
         """
-        :description: 处理邀请用户任务
+        :description: 处理邀请用户任务(被邀请人进入调用)
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
@@ -302,8 +302,9 @@ class InviteNewUserHandler(ClientBaseHandler):
         check_act_info_release = invoke_result_data.data["check_act_info_release"] if invoke_result_data.data.__contains__("check_act_info_release") else True
         check_act_module_release = invoke_result_data.data["check_act_module_release"] if invoke_result_data.data.__contains__("check_act_module_release") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
-        close_invite_limit = invoke_result_data.data["close_invite_limit"] if invoke_result_data.data.__contains__("close_invite_limit") else False
-        is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else False
+        close_invite_limit = invoke_result_data.data["close_invite_limit"] if invoke_result_data.data.__contains__("close_invite_limit") else False #是否关闭邀请限制
+        is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else False #是否统计
+        is_receive_reward = invoke_result_data.data["is_receive_reward"] if invoke_result_data.data.__contains__("is_receive_reward") else False #是否直接领取奖励
 
         stat_base_model = StatBaseModel(context=self)
         if is_stat == True:
@@ -319,7 +320,11 @@ class InviteNewUserHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success(invoke_result_data.data)
+        if is_receive_reward == True:
+            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=from_user_id, login_token='', task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=4, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=False, info_json=None, check_act_info_release=False, check_act_module_release=False)
+            if invoke_result_data.success == True:
+                return self.response_json_success(invoke_result_data.data)
+        return self.response_json_success(0)
 
 
 class InviteJoinMemberHandler(ClientBaseHandler):
@@ -355,6 +360,7 @@ class InviteJoinMemberHandler(ClientBaseHandler):
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         close_invite_limit = invoke_result_data.data["close_invite_limit"] if invoke_result_data.data.__contains__("close_invite_limit") else False
+        is_receive_reward = invoke_result_data.data["is_receive_reward"] if invoke_result_data.data.__contains__("is_receive_reward") else False  #是否直接领取奖励
         app_key, app_secret = self.get_app_key_secret()
         app_base_model = AppBaseModel(context=self)
         app_info_dict = app_base_model.get_app_info_dict(app_id)
@@ -366,7 +372,11 @@ class InviteJoinMemberHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success(invoke_result_data.data)
+        if is_receive_reward == True:
+            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=from_user_id, login_token='', task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=5, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=False, info_json=None, check_act_info_release=False, check_act_module_release=False)
+            if invoke_result_data.success == True:
+                return self.response_json_success(invoke_result_data.data)
+        return self.response_json_success(0)
 
 
 class CollectGoodsHandler(ClientBaseHandler):
@@ -400,6 +410,7 @@ class CollectGoodsHandler(ClientBaseHandler):
             invoke_result_data.data = {}
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
+        is_receive_reward = invoke_result_data.data["is_receive_reward"] if invoke_result_data.data.__contains__("is_receive_reward") else False #是否直接领取奖励
         invoke_result_data = task_base_model.process_collect_goods(app_id, act_id, module_id, user_id, login_token, goods_id, self.__class__.__name__, check_user_nick, continue_request_expire)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -407,8 +418,11 @@ class CollectGoodsHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        del invoke_result_data.data["act_info_dict"], invoke_result_data.data["act_module_dict"], invoke_result_data.data["user_info_dict"], invoke_result_data.data["identifier"], invoke_result_data.data["request_queue_name"]
-        return self.response_json_success(invoke_result_data.data)
+        if is_receive_reward == True:
+            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token=login_token, task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=8, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=False, info_json=None, check_act_info_release=False, check_act_module_release=False)
+            if invoke_result_data.success == True:
+                return self.response_json_success(invoke_result_data.data)
+        return self.response_json_success(0)
 
 
 class BrowseGoodsHandler(ClientBaseHandler):
@@ -443,6 +457,7 @@ class BrowseGoodsHandler(ClientBaseHandler):
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         daily_repeat_browse = invoke_result_data.data["daily_repeat_browse"] if invoke_result_data.data.__contains__("daily_repeat_browse") else False
+        is_receive_reward = invoke_result_data.data["is_receive_reward"] if invoke_result_data.data.__contains__("is_receive_reward") else False  #是否直接领取奖励
         invoke_result_data = task_base_model.process_browse_goods(app_id, act_id, module_id, user_id, login_token, goods_id, self.__class__.__name__, daily_repeat_browse, check_user_nick, continue_request_expire)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -450,8 +465,11 @@ class BrowseGoodsHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        del invoke_result_data.data["act_info_dict"], invoke_result_data.data["act_module_dict"], invoke_result_data.data["user_info_dict"], invoke_result_data.data["identifier"], invoke_result_data.data["request_queue_name"]
-        return self.response_json_success(invoke_result_data.data)
+        if is_receive_reward == True:
+            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token=login_token, task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=9, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=False, info_json=None, check_act_info_release=False, check_act_module_release=False)
+            if invoke_result_data.success == True:
+                return self.response_json_success(invoke_result_data.data)
+        return self.response_json_success(0)
 
 
 class FavorStoreHandler(ClientBaseHandler):
@@ -579,6 +597,7 @@ class BrowseSiteHandler(ClientBaseHandler):
             invoke_result_data.data = {}
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
+        is_receive_reward = invoke_result_data.data["is_receive_reward"] if invoke_result_data.data.__contains__("is_receive_reward") else False  #是否直接领取奖励
         invoke_result_data = task_base_model.process_browse_site(app_id, act_id, module_id, user_id, login_token, task_type, task_sub_type, self.__class__.__name__, check_user_nick, continue_request_expire)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -586,7 +605,12 @@ class BrowseSiteHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success(invoke_result_data.data)
+        if is_receive_reward == True:
+            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token=login_token, task_id=0, task_sub_type=task_sub_type, handler_name=self.__class__.__name__, request_code=self.request_code, task_type=task_type, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=False, info_json=None, check_act_info_release=False, check_act_module_release=False)
+            if invoke_result_data.success == True:
+                return self.response_json_success(invoke_result_data.data)
+        return self.response_json_success(0)
+
 
 
 class ShareHandler(ClientBaseHandler):
@@ -619,6 +643,7 @@ class ShareHandler(ClientBaseHandler):
         check_new_user = invoke_result_data.data["check_new_user"] if invoke_result_data.data.__contains__("check_new_user") else False
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
+        is_receive_reward = invoke_result_data.data["is_receive_reward"] if invoke_result_data.data.__contains__("is_receive_reward") else False  #是否直接领取奖励
         invoke_result_data = task_base_model.process_share(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, check_new_user, check_user_nick, continue_request_expire)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -626,4 +651,8 @@ class ShareHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success(invoke_result_data.data)
+        if is_receive_reward == True:
+            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token=login_token, task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=14, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=False, info_json=None, check_act_info_release=False, check_act_module_release=False)
+            if invoke_result_data.success == True:
+                return self.response_json_success(invoke_result_data.data)
+        return self.response_json_success(0)
