@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2023-01-04 16:24:28
+@LastEditTime: 2023-02-15 13:33:05
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -35,12 +35,13 @@ class LoginHandler(ClientBaseHandler):
         app_id = self.get_app_id()
         open_id = self.get_param("open_id")
         user_nick = self.get_user_nick()
+        mix_nick = self.get_param("mix_nick")
         act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
         avatar = self.get_param("avatar")
         code = self.get_param("code", "")
         anonymous_code = self.get_param("anonymous_code", "")
-        pt = self.get_param("pt", "tb")  #tb淘宝 tt抖音 wx微信 qq h5
+        pt = self.get_param("pt", "tb")  #tb淘宝 tt抖音 wx微信 jd京东 qq h5
 
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
@@ -65,7 +66,7 @@ class LoginHandler(ClientBaseHandler):
             login_ip = self.get_param("source_ip")
 
         user_base_model = UserBaseModel(context=self)
-        invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, user_nick, avatar, union_id, login_ip, is_update_user_nick)
+        invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, user_nick, avatar, union_id, login_ip, is_update_user_nick, mix_nick)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data.data["user_nick"] = CryptographyHelper.emoji_base64_to_emoji(invoke_result_data.data["user_nick"])
