@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2022-04-24 15:15:19
-@LastEditTime: 2022-11-24 11:45:09
+@LastEditTime: 2022-11-29 10:47:59
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -65,7 +65,7 @@ def filter_check_current_limit():
             app_id = self.get_app_id()
             app_info_dict = app_base_model.get_app_info_dict(app_id,True,"current_limit_count")
             if app_info_dict and RiskManageHelper.check_current_limit(app_id, app_info_dict["current_limit_count"]) == True:
-                self.response_json_error("current_limit", "系统繁忙,请稍后再试")
+                self.response_json_error("current_limit", "当前人数过多,请稍后再试")
                 return
 
             return handler(self, **args)
