@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2023-02-08 14:33:11
+@LastEditTime: 2023-02-13 18:17:44
 @LastEditors: HuangJianYi
 @Description: 活动模块
 """
@@ -259,9 +259,12 @@ class ActInfoListHandler(ClientBaseHandler):
             return self.response_json_success({"data": []})
         if not app_id:
             return self.response_json_success({"data": []})
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id asc"
         app_base_model = AppBaseModel(context=self)
         act_base_model = ActBaseModel(context=self)
-        page_list, total = act_base_model.get_act_info_list(app_id, act_name, is_del, page_size, page_index, False, act_type, is_release)
+        page_list, total = act_base_model.get_act_info_list(app_id, act_name, is_del, page_size, page_index, False, act_type, is_release, order_by)
         for page in page_list:
             page["online_url"] = app_base_model.get_online_url(act_id=page['id'], app_id=app_id, act_type=page['act_type'])
             page["live_url"] = app_base_model.get_live_url(app_id)
