@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 10:43:58
-@LastEditTime: 2022-10-17 17:33:38
+@LastEditTime: 2023-02-09 19:32:14
 @LastEditors: HuangJianYi
 @Description: 应用模块
 """
@@ -119,9 +119,9 @@ class VersionUpgradeHandler(ClientBaseHandler):
         app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
         if not app_info:
             return self.response_json_error("no_app", "小程序不存在")
-        test_config = config.get_value("test_config",{})
+        test_config = share_config.get_value("test_config", {})
         test_client_ver = test_config.get("client_ver","")
-        client_template_id = config.get_value("client_template_id")
+        client_template_id = share_config.get_value("client_template_id")
         #配置文件指定账号升级
         store_user_nick = user_nick.split(':')[0]
         if test_client_ver and store_user_nick and store_user_nick == test_config.get("user_nick",""):
