@@ -166,6 +166,11 @@ class ActPrizeListHandler(ClientBaseHandler):
             return self.response_json_success({"data": []})
         prize_base_model = PrizeBaseModel(context=self)
         page_list, total = prize_base_model.get_act_prize_list(app_id, act_id, module_id, prize_name, 0, is_del, page_size, page_index, order_by=order_by, condition=condition, params=params, field=field, is_cache=False)
+        for page in page_list:
+            if page.__contains__("prize_detail_json"):
+                page["prize_detail_json"] = SevenHelper.json_loads(page["prize_detail_json"]) if page["prize_detail_json"] else []
+            if page.__contains__("sku_json"):
+                page["sku_json"] = SevenHelper.json_loads(page["sku_json"]) if page["sku_json"] else []
         ref_params = {}
         page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
         return self.response_json_success(page_info)
