@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-10-25 18:00:46
-@LastEditTime: 2022-12-07 15:16:04
+@LastEditTime: 2022-12-13 15:06:40
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -14,7 +14,7 @@ from seven_cloudapp_frame.libs.customize.redis_helper import *
 
 class CounterHelper:
     """
-    :description: 计数帮助类 计数在redis的有效时间默认只有半年  配置字段说明{"expire":计数过期时间，单位秒,"计数key":{"db_connect_key": 上下文,"table_name": 表名,"id_field_name": 主键字段名,"value_field_name": 返回字段名}}
+    :description: 计数帮助类 配置字段说明{"expire":计数过期时间，单位秒,"计数key":{"db_connect_key": 上下文,"table_name": 表名,"id_field_name": 主键字段名,"value_field_name": 返回字段名}}
     :sence:使用场景：1.珀莱雅H5评论列表走缓存，评论数和喜欢数又想保证计数实时 2.库存走reids并自动从数据库同步redis
     """
     logger_error = Logger.get_logger_by_name("log_error")
@@ -47,7 +47,7 @@ class CounterHelper:
             db_update_count = 0
             if sync_update_db == True and table_name and id_field_name and value_field_name:
                 db = MySQLHelper(config.get_value(db_connect_key))
-                sql = f'update {table_name} set {value_field_name}={value_field_name}+{value} where {id_field_name}=' + '%s'
+                sql = f'UPDATE {table_name} SET {value_field_name}={value_field_name}+{value} WHERE {id_field_name}=' + '%s'
                 db_update_count = db.update(sql, [object_id])
             if sync_update_db == False or (sync_update_db == True and db_update_count > 0):
                 init = RedisExHelper.init()
@@ -162,7 +162,7 @@ class CounterHelper:
             value_field_name = counter_config_dict.get("value_field_name", "")
             if table_name and id_field_name and value_field_name:
                 db = MySQLHelper(config.get_value(db_connect_key))
-                db_value = db.query(f'select {value_field_name} from {table_name} where {id_field_name}=' + '%s limit 1;', params=[object_id])
+                db_value = db.query(f'SELECT {value_field_name} FROM {table_name} WHERE {id_field_name}=' + '%s LIMIT 1;', params=[object_id])
                 if len(db_value) <= 0:
                     db_value = 0
                 else:
