@@ -9,6 +9,7 @@
 import oss2
 import os
 from seven_framework import *
+from seven_cloudapp_frame.libs.common import *
 
 
 class OSS2Helper:
@@ -22,7 +23,7 @@ class OSS2Helper:
 
     @classmethod
     def get_oss_config(self):
-        oss_config = config.get_value("oss_config")
+        oss_config = share_config.get_value("oss_config")
         if not oss_config:
             oss_config = {}
             oss_config["ak_id"] = "LTAI4GAV8q6wxi2gqispR4my"
@@ -35,7 +36,7 @@ class OSS2Helper:
         self.bucket_name = oss_config.get("bucket_name","")
         self.end_point = oss_config.get("end_point","")
         self.demain = oss_config.get("demain","")
-    
+
     @classmethod
     def upload(self, file_name, local_file='', folder='', is_auto_name=True, data=None):
         """
@@ -103,7 +104,7 @@ class OSS2Helper:
                     os.makedirs("temp")
                 path = "temp/" + UUIDHelper.get_uuid() + ".xlsx"
                 ExcelHelper.export(import_data, path)
-                resource_path = self.upload("", path, config.get_value("oss_folder"), False)
+                resource_path = self.upload("", path, share_config.get_value("oss_folder"), False)
                 os.remove(path)
             except Exception as ex:
                 self.logger_error("【数据导入excel】" + traceback.format_exc())
