@@ -2,12 +2,13 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2022-07-27 15:52:08
+@LastEditTime: 2023-02-10 09:57:56
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
 from seven_framework import *
 from seven_framework.redis import *
+from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.libs.customize.redis_helper import RedisExHelper
 from seven_cloudapp_frame.libs.customize.time_helper import TimeExHelper
 
@@ -40,7 +41,7 @@ class SevenHelper:
         :return: bool true-代表连续请求进行限制，false-代表跳过限制
         :last_editors: HuangJianYi
         """
-        if config.get_value("is_pressure_test",False): #是否进行压力测试
+        if share_config.get_value("is_pressure_test",False): #是否进行压力测试
             return False
         redis_init = self.redis_init()
         post_value = redis_init.incr(cache_key,1)
