@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2022-12-08 20:50:40
+@LastEditTime: 2023-02-10 10:21:25
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -20,6 +20,7 @@ from Crypto.PublicKey import RSA
 from Crypto.Signature import PKCS1_v1_5
 from Crypto.Hash import SHA256
 import string
+from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_framework.base_model import *
 from seven_cloudapp_frame.models.seven_model import InvokeResultData
@@ -42,7 +43,7 @@ class WeChatHelper:
         :return: 返回网页授权链接
         :last_editors: HuangJianYi
         """
-        app_id = app_id if app_id else config.get_value("app_id")
+        app_id = app_id if app_id else share_config.get_value("app_id")
         authorize_url = "https://open.weixin.qq.com/connect/oauth2/authorize?appid={0}&redirect_uri={1}&response_type=code&scope={2}&state={3}&connect_redirect=1#wechat_redirect".format(app_id, CodingHelper.url_encode(redirect_uri), scope, CodingHelper.url_encode(state))
         return authorize_url
 
@@ -57,8 +58,8 @@ class WeChatHelper:
         :return: 返回用户信息{ "openid": "OPENID","nickname": NICKNAME,"sex": 1,"province":"PROVINCE","city":"CITY","country":"COUNTRY","headimgurl":"https://thirdwx.qlogo.cn/mmopen/g3MonUZtNHkdmzicIlibx6iaFqAc56vxLSUfpb6n5WKSYVY0ChQKkiaJSgQ1dZuTOgvLLrhJbERQQ4eMsv84eavHiaiceqxibJxCfHe/46","privilege":[ "PRIVILEGE1" "PRIVILEGE2"],"unionid": "o6_bmasdasdsad6_2sgVt7hMZOPfL"}
         :last_editors: HuangJianYi
         """
-        app_id = app_id if app_id else config.get_value("app_id")
-        app_secret = app_secret if app_secret else config.get_value("app_secret")
+        app_id = app_id if app_id else share_config.get_value("app_id")
+        app_secret = app_secret if app_secret else share_config.get_value("app_secret")
         invoke_result_data = InvokeResultData()
         param = {
             'code': code,  # 用户点击按钮跳转到微信授权页, 微信处理完后重定向到redirect_uri, 并给我们加上code=xxx的参数, 这个code就是我们需要的
@@ -107,11 +108,11 @@ class WeChatHelper:
         :return: 返回ticket
         :last_editors: HuangJianYi
         """
-        app_id = app_id if app_id else config.get_value("app_id")
+        app_id = app_id if app_id else share_config.get_value("app_id")
 
         invoke_result_data = InvokeResultData()
         try:
-            redis_init = SevenHelper.redis_init(config_dict=config.get_value("platform_redis"))
+            redis_init = SevenHelper.redis_init(config_dict=share_config.get_value("platform_redis"))
             redis_key = f"wechat_jsapi_ticket:{str(app_id)}"
             jsapi_ticket = redis_init.get(redis_key)
             if not jsapi_ticket:
@@ -138,8 +139,8 @@ class WeChatHelper:
         :return: 返回ticket
         :last_editors: HuangJianYi
         """
-        app_id = app_id if app_id else config.get_value("app_id")
-        app_secret = app_secret if app_secret else config.get_value("app_secret")
+        app_id = app_id if app_id else share_config.get_value("app_id")
+        app_secret = app_secret if app_secret else share_config.get_value("app_secret")
 
         invoke_result_data = InvokeResultData()
         for i in range(2):
@@ -186,7 +187,7 @@ class WeChatHelper:
         :return: 返回分享请求参数
         :last_editors: HuangJianYi
         """
-        app_id = app_id if app_id else config.get_value("app_id")
+        app_id = app_id if app_id else share_config.get_value("app_id")
 
         invoke_result_data = InvokeResultData()
         request_url = request_url.split('#')[0]
@@ -214,8 +215,8 @@ class WeChatHelper:
         :return: 返回字典包含字段 session_key,openid
         :last_editors: HuangJianYi
         """
-        app_id = app_id if app_id else config.get_value("app_id")
-        app_secret = app_secret if app_secret else config.get_value("app_secret")
+        app_id = app_id if app_id else share_config.get_value("app_id")
+        app_secret = app_secret if app_secret else share_config.get_value("app_secret")
         invoke_result_data = InvokeResultData()
         redis_key = f"{app_id}_wechat_login_code:{str(code)}"
         redis_init = SevenHelper.redis_init()
@@ -268,13 +269,13 @@ class WeChatHelper:
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = app_id if app_id else config.get_value("app_id")
-        app_secret = app_secret if app_secret else config.get_value("app_secret")
+        app_id = app_id if app_id else share_config.get_value("app_id")
+        app_secret = app_secret if app_secret else share_config.get_value("app_secret")
 
         invoke_result_data = InvokeResultData()
 
         try:
-            redis_init = SevenHelper.redis_init(config_dict=config.get_value("platform_redis"))
+            redis_init = SevenHelper.redis_init(config_dict=share_config.get_value("platform_redis"))
             redis_key = f"wechat_access_token:{str(app_id)}"
             if is_del == True:
                 redis_init.delete(redis_key)
@@ -305,8 +306,8 @@ class WeChatHelper:
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = app_id if app_id else config.get_value("app_id")
-        app_secret = app_secret if app_secret else config.get_value("app_secret")
+        app_id = app_id if app_id else share_config.get_value("app_id")
+        app_secret = app_secret if app_secret else share_config.get_value("app_secret")
 
         invoke_result_data = InvokeResultData()
         param = {
@@ -353,8 +354,8 @@ class WeChatHelper:
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = app_id if app_id else config.get_value("app_id")
-        app_secret = app_secret if app_secret else config.get_value("app_secret")
+        app_id = app_id if app_id else share_config.get_value("app_id")
+        app_secret = app_secret if app_secret else share_config.get_value("app_secret")
         invoke_result_data = InvokeResultData()
         for i in range(2):
             if i == 0:
@@ -444,8 +445,8 @@ class WeChatHelper:
         :return: 图片二进制 数据类型Array<byte>
         :last_editors: HuangJianYi
         """
-        app_id = app_id if app_id else config.get_value("app_id")
-        app_secret = app_secret if app_secret else config.get_value("app_secret")
+        app_id = app_id if app_id else share_config.get_value("app_id")
+        app_secret = app_secret if app_secret else share_config.get_value("app_secret")
 
         invoke_result_data = InvokeResultData()
         redis_init = SevenHelper.redis_init(decode_responses=False)
@@ -502,8 +503,8 @@ class WeChatHelper:
         :return: 图片二进制 数据类型Array<byte>
         :last_editors: HuangJianYi
         """
-        app_id = app_id if app_id else config.get_value("app_id")
-        app_secret = app_secret if app_secret else config.get_value("app_secret")
+        app_id = app_id if app_id else share_config.get_value("app_id")
+        app_secret = app_secret if app_secret else share_config.get_value("app_secret")
 
         invoke_result_data = InvokeResultData()
         redis_init = SevenHelper.redis_init(decode_responses=False)
@@ -563,8 +564,8 @@ class WeChatHelper:
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        app_id = app_id if app_id else config.get_value("app_id")
-        app_secret = app_secret if app_secret else config.get_value("app_secret")
+        app_id = app_id if app_id else share_config.get_value("app_id")
+        app_secret = app_secret if app_secret else share_config.get_value("app_secret")
         invoke_result_data = InvokeResultData()
         for i in range(2):
             if i == 0:
@@ -611,8 +612,8 @@ class WeChatHelper:
         :return: 解密后的数据，用户信息或者手机号信息
         :last_editors: HuangJianYi
         """
-        app_id = app_id if app_id else config.get_value("app_id")
-        app_secret = app_secret if app_secret else config.get_value("app_secret")
+        app_id = app_id if app_id else share_config.get_value("app_id")
+        app_secret = app_secret if app_secret else share_config.get_value("app_secret")
 
         data = None
         if code:
@@ -638,7 +639,7 @@ class WeChatHelper:
         :return: 解密后的数据，用户信息或者手机号信息
         :last_editors: HuangJianYi
         """
-        app_id = app_id if app_id else config.get_value("app_id")
+        app_id = app_id if app_id else share_config.get_value("app_id")
 
         data = {}
         try:
@@ -763,8 +764,8 @@ class WeChatPayRequest(object):
     logger_error = Logger.get_logger_by_name("log_error")
 
     def __init__(self, app_id="", api_key="", mch_id="", certificate_url="", private_key_url=""):
-        pay_config = config.get_value("wechat_pay")
-        self.app_id = app_id if app_id else config.get_value("app_id")
+        pay_config = share_config.get_value("wechat_pay")
+        self.app_id = app_id if app_id else share_config.get_value("app_id")
         self.api_key = api_key if api_key else pay_config["api_key"]
         self.mch_id = mch_id if mch_id else pay_config["mch_id"]
         self.certificate_url = certificate_url if certificate_url else pay_config["certificate_url"]
@@ -1096,7 +1097,7 @@ class WeChatPayReponse(object):
 
     def __init__(self, reponse_xml, api_key=""):
         self.data = WeChatHelper.xml_to_array(reponse_xml)
-        pay_config = config.get_value("wechat_pay")
+        pay_config = share_config.get_value("wechat_pay")
         self.api_key = api_key if api_key else pay_config["api_key"]
 
     def check_sign(self):
@@ -1138,7 +1139,7 @@ class WeChatRefundReponse(object):
 
     def __init__(self, reponse_xml, api_key=""):
         self.data = WeChatHelper.xml_to_array(reponse_xml)
-        pay_config = config.get_value("wechat_pay")
+        pay_config = share_config.get_value("wechat_pay")
         self.api_key = api_key if api_key else pay_config["api_key"]
 
     def get_data(self):
@@ -1215,8 +1216,8 @@ class WeChatPayV3Request(object):
 
     def __init__(self, app_id="", api_key="", mch_id="", mch_serial_no="", certificate_url="", private_key_url=""):
 
-        pay_config = config.get_value("wechat_pay", {})
-        self.app_id = app_id if app_id else config.get_value("app_id")
+        pay_config = share_config.get_value("wechat_pay", {})
+        self.app_id = app_id if app_id else share_config.get_value("app_id")
         self.mch_id = mch_id if mch_id else pay_config.get("mch_id", "")
         self.api_key = api_key if api_key else pay_config.get("api_key", "")
         self.mch_serial_no = mch_serial_no if mch_serial_no else pay_config.get("mch_serial_no", "")
