@@ -63,7 +63,7 @@ class ActBaseModel():
                 return None
         return act_info_dict
 
-    def get_act_info_list(self, app_id, act_name, is_del, page_size, page_index, is_cache=True, act_type=-1, is_release=-1):
+    def get_act_info_list(self, app_id, act_name, is_del, page_size, page_index, is_cache=True, act_type=-1, is_release=-1, order_by="id asc"):
         """
         :description: 获取活动信息列表
         :param app_id: 应用标识
@@ -73,10 +73,10 @@ class ActBaseModel():
         :param page_index: 页数
         :param is_cache: 是否缓存
         :param is_release: 是否发布（1是0否）
+        :param is_release: 是否发布（1是0否）
         :return: 
         :last_editors: HuangJianYi
         """
-        order_by = "id asc"
         condition_where = ConditionWhere()
         condition_where.add_condition("app_id=%s")
         params = [app_id]
