@@ -204,13 +204,13 @@ class CacheModel(BaseModel):
         list_row = self.get_dependency_cache(dependency_key,cache_key)
         if list_row and share_config.get_value("is_redis_cache",True) == True:
             if list_row == 'null':
-                return None
+                return []
             return self._BaseModel__row_entity_list(list_row)
         else:
             list_row = self.db.fetch_all_rows(sql, params)
             cache_value = deepcopy(list_row)
             if not cache_value:
-                cache_value = None
+                cache_value = []
             config_cache_expire = share_config.get_value("cache_expire",0)
             if config_cache_expire > 0:
                 cache_expire = config_cache_expire
