@@ -32,6 +32,7 @@ class UserAccount:
         self.open_id = ""  # open_id
         self.user_nick = ""  # 用户昵称
         self.user_nick_encrypt = ""  # 昵称加密值
+        self.mix_nick = ""  # 混淆昵称
         self.avatar = ""  # 头像
         self.user_state = 0  # 用户状态（0-正常，1-黑名单）
         self.full_name = ""  # 姓名
@@ -49,7 +50,7 @@ class UserAccount:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'union_id', 'open_id', 'user_nick', 'user_nick_encrypt', 'avatar', 'user_state','full_name','telephone','sex','birthday','certificate_type','certificate_no', 'relieve_date', 'create_date','create_ip', 'modify_date','login_date','login_ip']
+        return ['id', 'union_id', 'open_id', 'user_nick', 'user_nick_encrypt', 'mix_nick', 'avatar', 'user_state', 'full_name', 'telephone', 'sex', 'birthday', 'certificate_type', 'certificate_no', 'relieve_date', 'create_date', 'create_ip', 'modify_date', 'login_date', 'login_ip']
 
     @classmethod
     def get_primary_key(self):
