@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2023-02-10 10:45:31
+@LastEditTime: 2023-02-15 15:36:55
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -425,7 +425,7 @@ class OrderBaseModel(FrameBaseModel):
             return invoke_result_data
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"),context=self.context)
         user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb",{"app_id":app_id}), db_transaction=db_transaction, context=self.context)
-        prize_roster_model = PrizeRosterModel(self.get_business_sub_table("prize_roster_tb",{"app_id":app_id}), db_transaction=db_transaction, context=self.context)
+        prize_roster_model = PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb",{"app_id":app_id}), db_transaction=db_transaction, context=self.context)
         prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb",{"app_id":app_id}),db_transaction=db_transaction, context=self.context)
         prize_ids_list = []
         if prize_ids:
