@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:26:29
-@LastEditTime: 2022-10-20 20:39:23
+@LastEditTime: 2023-01-04 15:59:34
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -125,7 +125,7 @@ class PriceBaseModel():
         self._delete_price_gear_dependency_key(act_id)
         return invoke_result_data
 
-    def get_price_gear_list(self,app_id,act_id,page_size,page_index,order_by="id desc",is_del=0,is_cache=True):
+    def get_price_gear_list(self,app_id,act_id,page_size,page_index,order_by="id desc",is_del=0,is_cache=True, page_count_mode="total"):
         """
         :description: 获取价格档位列表
         :param app_id：应用标识
@@ -135,22 +135,23 @@ class PriceBaseModel():
         :param order_by：排序
         :param is_del：是否回收站1是0否
         :param is_cache：是否缓存
-        :return: list
+        :param page_count_mode: 分页计数模式 total-计算总数(默认) next-计算是否有下一页(bool) none-不计算
+        :return:
         :last_editors: HuangJianYi
         """
         condition = "app_id=%s and act_id=%s"
         if is_del == 1:
-            condition+=" and is_del=1"
+            condition += " and is_del=1"
         else:
-            condition+=" and is_del=0"
+            condition += " and is_del=0"
 
         params = [app_id,act_id]
         price_gear_model = PriceGearModel(context=self.context)
         if is_cache == True:
-            page_list, total = price_gear_model.get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,dependency_key=DependencyKey.price_gear_list(act_id))
+            page_list = price_gear_model.get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,dependency_key=DependencyKey.price_gear_list(act_id),page_count_mode=page_count_mode)
         else:
-            page_list, total = price_gear_model.get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params)
-        return page_list, total
+            page_list = price_gear_model.get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,page_count_mode=page_count_mode)
+        return page_list
 
     def update_price_gear_status(self,app_id,act_id,price_gear_id,is_del):
         """
