@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-04 13:41:15
-@LastEditTime: 2022-10-17 14:41:29
+@LastEditTime: 2023-01-04 15:25:52
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -62,7 +62,7 @@ class PrizeBaseModel():
                 return None
         return act_prize_dict
 
-    def get_act_prize_list(self,app_id,act_id,module_id,prize_name,ascription_type,is_del,page_size,page_index,order_by="sort_index desc,id asc",condition="",params=[],field="*",is_cache=True):
+    def get_act_prize_list(self,app_id,act_id,module_id,prize_name,ascription_type,is_del,page_size,page_index,order_by="sort_index desc,id asc",condition="",params=[],field="*",is_cache=True,page_count_mode="total"):
         """
         :description: 获取活动奖品列表
         :param app_id: 应用标识
@@ -78,6 +78,7 @@ class PrizeBaseModel():
         :param params：参数化数组
         :param field:查询字段
         :param is_cache: 是否缓存
+        :param page_count_mode: 分页计数模式 total-计算总数(默认) next-计算是否有下一页(bool) none-不计算       
         :return: 
         :last_editors: HuangJianYi
         """
@@ -100,10 +101,10 @@ class PrizeBaseModel():
             params_list.append(prize_name)
         act_prize_model = ActPrizeModel(context=self.context)
         if is_cache:
-            page_list, total = act_prize_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list,dependency_key=DependencyKey.act_prize_list(act_id,module_id))
+            page_list = act_prize_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list,dependency_key=DependencyKey.act_prize_list(act_id,module_id),page_count_mode=page_count_mode)
         else:
-            page_list, total = act_prize_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list)
-        return page_list, total
+            page_list = act_prize_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list,page_count_mode=page_count_mode)
+        return page_list
 
     def save_act_prize(self,app_id,act_id,module_id,prize_id,prize_name,prize_title,prize_pic,prize_detail_json,goods_id,goods_code,goods_code_list,goods_type,prize_type,prize_price,probability,chance,prize_limit,is_prize_notice,prize_total,is_surplus,lottery_type,tag_name,tag_id,is_sku,sku_json,sort_index,is_release,ascription_type=0,i1=0,i2=0,i3=0,i4=0,i5=0,s1='',s2='',s3='',s4='',s5='',d1='',d2=''):
         """
