@@ -2,10 +2,11 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2022-12-19 10:17:38
+@LastEditTime: 2023-02-09 19:35:23
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
+from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.libs.customize.seven_helper import SevenHelper
 from seven_top import top
 from seven_cloudapp_frame.models.db_models.base.base_info_model import *
@@ -43,7 +44,7 @@ class TopBaseModel():
         app_name = base_info.product_name
         description = base_info.product_desc
         icon = base_info.product_icon
-        template_id = config.get_value("client_template_id")
+        template_id = share_config.get_value("client_template_id")
         template_version = base_info.client_ver
         app_info_model = AppInfoModel(context=self.context)
         app_info = None
@@ -120,7 +121,7 @@ class TopBaseModel():
         try:
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.MiniappTemplateInstantiateRequest()
-            req.clients = config.get_value("instantiate_clients","taobao,tmall")
+            req.clients = share_config.get_value("instantiate_clients","taobao,tmall")
             req.description = description
             req.ext_json = "{ \"name\":\"" + app_name + "\"}"
             req.icon = icon
@@ -211,7 +212,7 @@ class TopBaseModel():
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.MiniappTemplateUpdateappRequest()
 
-            req.clients = config.get_value("instantiate_clients","taobao,tmall")
+            req.clients = share_config.get_value("instantiate_clients","taobao,tmall")
             req.app_id = app_id
             req.template_id = client_template_id
             req.template_version = client_ver
@@ -516,7 +517,7 @@ class TopBaseModel():
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.MiniappTemplateOnlineappRequest()
 
-            req.clients = config.get_value("instantiate_clients","taobao,tmall")
+            req.clients = share_config.get_value("instantiate_clients","taobao,tmall")
             req.app_id = app_id
             req.template_id = template_id
             req.template_version = template_version
@@ -1013,7 +1014,7 @@ class TopBaseModel():
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.AlibabaBenefitQueryRequest()
             req.ename = right_ename
-            req.app_name = "promotioncenter-" + config.get_value("server_template_id")
+            req.app_name = "promotioncenter-" + share_config.get_value("server_template_id")
             req.award_type = "1"
             resp = req.getResponse(access_token)
             if is_log:
@@ -1063,7 +1064,7 @@ class TopBaseModel():
             req.receiver_id = open_id
             req.user_type = "taobao"
             req.unique_id = str(open_id) + str(right_ename) + str(TimeHelper.get_now_timestamp())
-            req.app_name = "promotioncenter-" + config.get_value("server_template_id")
+            req.app_name = "promotioncenter-" + share_config.get_value("server_template_id")
             resp = req.getResponse(access_token)
             if is_log:
                 log_info = str(resp) + "【access_token】：" + access_token + "【发放优惠劵】"
@@ -1408,7 +1409,7 @@ class TopBaseModel():
                 return json.loads(vas_subscribe_get_response)
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.VasSubscribeGetRequest()
-            req.article_code = config.get_value("article_code")
+            req.article_code = share_config.get_value("article_code")
             req.nick = user_nick
             resp = req.getResponse(access_token)
             if is_log:
@@ -1441,7 +1442,7 @@ class TopBaseModel():
         try:
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.MiniappShorturlCreateRequest()
-            req.article_code = config.get_value("article_code")
+            req.article_code = share_config.get_value("article_code")
             req.miniapp_url = url
             resp = req.getResponse(access_token)
             if is_log:
