@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2023-02-06 11:58:07
+@LastEditTime: 2023-02-15 13:33:50
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -155,7 +155,7 @@ class UserBaseModel(FrameBaseModel):
         top_base_model = TopBaseModel(context=self.context)
         return top_base_model.get_join_member_url(access_token, app_key, app_secret, is_log)
 
-    def save_user_by_openid(self, app_id, act_id, open_id, user_nick, avatar, union_id="", login_ip="", is_update_user_nick=True):
+    def save_user_by_openid(self, app_id, act_id, open_id, user_nick, avatar, union_id="", login_ip="", is_update_user_nick=True, mix_nick=''):
         """
         :description: 获取或更新用户信息（主要用于登录）
         :param app_id：应用标识
@@ -166,6 +166,7 @@ class UserBaseModel(FrameBaseModel):
         :param union_id：union_id
         :param login_ip：登录ip地址
         :param is_update_user_nick：是否更新用户昵称
+        :param mix_nick：混淆昵称
         :return: 返回用户信息
         :last_editors: HuangJianYi
         """
@@ -197,6 +198,7 @@ class UserBaseModel(FrameBaseModel):
                 user_account.open_id = open_id
                 user_account.user_nick = CryptographyHelper.emoji_to_emoji_base64(user_nick)
                 user_account.user_nick_encrypt = CryptographyHelper.base64_encrypt(user_nick) if user_nick else ""
+                user_account.mix_nick = mix_nick
                 user_account.avatar = avatar
                 user_account.user_state = 0
                 user_account.create_date = now_datetime
@@ -213,9 +215,11 @@ class UserBaseModel(FrameBaseModel):
                     user_account.avatar = avatar
                 if union_id and user_account.union_id != union_id:
                     user_account.union_id = union_id
+                if mix_nick:
+                    user_account.mix_nick = mix_nick
                 user_account.login_date = now_datetime
                 user_account.login_ip = login_ip
-                user_account_model.update_entity(user_account, "user_nick,user_nick_encrypt,avatar,union_id,login_date,login_ip")
+                user_account_model.update_entity(user_account, "user_nick,user_nick_encrypt,mix_nick,avatar,union_id,login_date,login_ip")
 
             user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
             if not user_info:
